package de.intevation.flys.artifacts.model;

import java.util.Arrays;

import org.apache.log4j.Logger;

public class Calculation2
extends      Calculation
{
    private static Logger logger = Logger.getLogger(Calculation2.class);

    protected double km;

    public Calculation2() {
    }

    public Calculation2(double km) {
        this.km = km;
    }

    public CalculationResult calculate(WstValueTable wst) {

        logger.debug("Calculation2.calculate");

        double [][] wqs = wst.interpolateWQ(km, this);

        if (wqs == null || wqs[0].length == 0) {
            logger.debug("Cannot compute discharge curve data.");
            addProblem("Cannot compute discharge curve data.");
            return new CalculationResult(new WQKms[0], this);
        }

        double [] ws = wqs[0];
        double [] qs = wqs[1];
        double [] kms = new double[ws.length];

        Arrays.fill(kms, km);

        WQKms wqkms = new WQKms(kms, qs, ws, String.valueOf(km));

        if (hasProblems()) {
            logger.debug("found + "+numProblems()+" problems.");
            wqkms.removeNaNs();
        }

        return new CalculationResult(new WQKms[] { wqkms }, this);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
